# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeTestCaseMonitorInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'threshold': 'MonitorThreshold',
        'is_subset_metric': 'bool',
        'excluded_transforms': 'MonitorExcludedTransforms'
    }

    attribute_map = {
        'threshold': 'threshold',
        'is_subset_metric': 'isSubsetMetric',
        'excluded_transforms': 'excludedTransforms'
    }

    def __init__(self, threshold=None, is_subset_metric=None, excluded_transforms=None):  # noqa: E501
        """RimeTestCaseMonitorInfo - a model defined in Swagger"""  # noqa: E501
        self._threshold = None
        self._is_subset_metric = None
        self._excluded_transforms = None
        self.discriminator = None
        if threshold is not None:
            self.threshold = threshold
        if is_subset_metric is not None:
            self.is_subset_metric = is_subset_metric
        if excluded_transforms is not None:
            self.excluded_transforms = excluded_transforms

    @property
    def threshold(self):
        """Gets the threshold of this RimeTestCaseMonitorInfo.  # noqa: E501


        :return: The threshold of this RimeTestCaseMonitorInfo.  # noqa: E501
        :rtype: MonitorThreshold
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this RimeTestCaseMonitorInfo.


        :param threshold: The threshold of this RimeTestCaseMonitorInfo.  # noqa: E501
        :type: MonitorThreshold
        """

        self._threshold = threshold

    @property
    def is_subset_metric(self):
        """Gets the is_subset_metric of this RimeTestCaseMonitorInfo.  # noqa: E501


        :return: The is_subset_metric of this RimeTestCaseMonitorInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_subset_metric

    @is_subset_metric.setter
    def is_subset_metric(self, is_subset_metric):
        """Sets the is_subset_metric of this RimeTestCaseMonitorInfo.


        :param is_subset_metric: The is_subset_metric of this RimeTestCaseMonitorInfo.  # noqa: E501
        :type: bool
        """

        self._is_subset_metric = is_subset_metric

    @property
    def excluded_transforms(self):
        """Gets the excluded_transforms of this RimeTestCaseMonitorInfo.  # noqa: E501


        :return: The excluded_transforms of this RimeTestCaseMonitorInfo.  # noqa: E501
        :rtype: MonitorExcludedTransforms
        """
        return self._excluded_transforms

    @excluded_transforms.setter
    def excluded_transforms(self, excluded_transforms):
        """Sets the excluded_transforms of this RimeTestCaseMonitorInfo.


        :param excluded_transforms: The excluded_transforms of this RimeTestCaseMonitorInfo.  # noqa: E501
        :type: MonitorExcludedTransforms
        """

        self._excluded_transforms = excluded_transforms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeTestCaseMonitorInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeTestCaseMonitorInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResetpasswordUserIdUuidBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'object',
        'old_password': 'str',
        'new_password': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'old_password': 'oldPassword',
        'new_password': 'newPassword'
    }

    def __init__(self, user_id=None, old_password=None, new_password=None):  # noqa: E501
        """ResetpasswordUserIdUuidBody - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._old_password = None
        self._new_password = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        if old_password is not None:
            self.old_password = old_password
        self.new_password = new_password

    @property
    def user_id(self):
        """Gets the user_id of this ResetpasswordUserIdUuidBody.  # noqa: E501

        Unique ID of an object in RIME.  # noqa: E501

        :return: The user_id of this ResetpasswordUserIdUuidBody.  # noqa: E501
        :rtype: object
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ResetpasswordUserIdUuidBody.

        Unique ID of an object in RIME.  # noqa: E501

        :param user_id: The user_id of this ResetpasswordUserIdUuidBody.  # noqa: E501
        :type: object
        """

        self._user_id = user_id

    @property
    def old_password(self):
        """Gets the old_password of this ResetpasswordUserIdUuidBody.  # noqa: E501


        :return: The old_password of this ResetpasswordUserIdUuidBody.  # noqa: E501
        :rtype: str
        """
        return self._old_password

    @old_password.setter
    def old_password(self, old_password):
        """Sets the old_password of this ResetpasswordUserIdUuidBody.


        :param old_password: The old_password of this ResetpasswordUserIdUuidBody.  # noqa: E501
        :type: str
        """

        self._old_password = old_password

    @property
    def new_password(self):
        """Gets the new_password of this ResetpasswordUserIdUuidBody.  # noqa: E501


        :return: The new_password of this ResetpasswordUserIdUuidBody.  # noqa: E501
        :rtype: str
        """
        return self._new_password

    @new_password.setter
    def new_password(self, new_password):
        """Sets the new_password of this ResetpasswordUserIdUuidBody.


        :param new_password: The new_password of this ResetpasswordUserIdUuidBody.  # noqa: E501
        :type: str
        """
        if new_password is None:
            raise ValueError("Invalid value for `new_password`, must not be `None`")  # noqa: E501

        self._new_password = new_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResetpasswordUserIdUuidBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResetpasswordUserIdUuidBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
